==> apo-ws-client-6.00.51.1-sources.jar: fr/univlorraine/apowsclient/creationSE/ParametrageAnnuelCeDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ParametrageAnnuelCeDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ParametrageAnnuelCeDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codAnneeUni" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codSectionCnu" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codSectionCnuSec" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codRegroupementSectionCnu" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temCalculCharge" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temNormeContrainte" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temElpPorteur" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="commentaireParamCE" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codEtpPorteuse" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codVrsVetPorteuse" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *         &lt;element name="listElpPorte" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauElpPorteDTO" minOccurs="0"/&gt;
 *         &lt;element name="listTypHeur" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauTypeHeureDTO" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ParametrageAnnuelCeDTO", namespace = "ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codAnneeUni",
    "codSectionCnu",
    "codSectionCnuSec",
    "codRegroupementSectionCnu",
    "temCalculCharge",
    "temNormeContrainte",
    "temElpPorteur",
    "commentaireParamCE",
    "codEtpPorteuse",
    "codVrsVetPorteuse",
    "listElpPorte",
    "listTypHeur"
})
public class ParametrageAnnuelCeDTO {

    @XmlElement(required = true)
    protected String codAnneeUni;
    protected String codSectionCnu;
    protected String codSectionCnuSec;
    @XmlElementRef(name = "codRegroupementSectionCnu", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codRegroupementSectionCnu;
    @XmlElementRef(name = "temCalculCharge", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temCalculCharge;
    @XmlElementRef(name = "temNormeContrainte", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temNormeContrainte;
    @XmlElementRef(name = "temElpPorteur", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temElpPorteur;
    @XmlElementRef(name = "commentaireParamCE", type = JAXBElement.class, required = false)
    protected JAXBElement<String> commentaireParamCE;
    @XmlElementRef(name = "codEtpPorteuse", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codEtpPorteuse;
    @XmlElementRef(name = "codVrsVetPorteuse", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codVrsVetPorteuse;
    @XmlElementRef(name = "listElpPorte", type = JAXBElement.class, required = false)
    protected JAXBElement<TableauElpPorteDTO2> listElpPorte;
    @XmlElementRef(name = "listTypHeur", type = JAXBElement.class, required = false)
    protected JAXBElement<TableauTypeHeureDTO2> listTypHeur;

    /**
     * Obtient la valeur de la propriété codAnneeUni.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodAnneeUni() {
        return codAnneeUni;
    }

    /**
     * Définit la valeur de la propriété codAnneeUni.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodAnneeUni(String value) {
        this.codAnneeUni = value;
    }

    /**
     * Obtient la valeur de la propriété codSectionCnu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodSectionCnu() {
        return codSectionCnu;
    }

    /**
     * Définit la valeur de la propriété codSectionCnu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodSectionCnu(String value) {
        this.codSectionCnu = value;
    }

    /**
     * Obtient la valeur de la propriété codSectionCnuSec.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodSectionCnuSec() {
        return codSectionCnuSec;
    }

    /**
     * Définit la valeur de la propriété codSectionCnuSec.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodSectionCnuSec(String value) {
        this.codSectionCnuSec = value;
    }

    /**
     * Obtient la valeur de la propriété codRegroupementSectionCnu.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodRegroupementSectionCnu() {
        return codRegroupementSectionCnu;
    }

    /**
     * Définit la valeur de la propriété codRegroupementSectionCnu.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodRegroupementSectionCnu(JAXBElement<String> value) {
        this.codRegroupementSectionCnu = value;
    }

    /**
     * Obtient la valeur de la propriété temCalculCharge.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemCalculCharge() {
        return temCalculCharge;
    }

    /**
     * Définit la valeur de la propriété temCalculCharge.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemCalculCharge(JAXBElement<String> value) {
        this.temCalculCharge = value;
    }

    /**
     * Obtient la valeur de la propriété temNormeContrainte.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemNormeContrainte() {
        return temNormeContrainte;
    }

    /**
     * Définit la valeur de la propriété temNormeContrainte.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemNormeContrainte(JAXBElement<String> value) {
        this.temNormeContrainte = value;
    }

    /**
     * Obtient la valeur de la propriété temElpPorteur.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemElpPorteur() {
        return temElpPorteur;
    }

    /**
     * Définit la valeur de la propriété temElpPorteur.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemElpPorteur(JAXBElement<String> value) {
        this.temElpPorteur = value;
    }

    /**
     * Obtient la valeur de la propriété commentaireParamCE.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCommentaireParamCE() {
        return commentaireParamCE;
    }

    /**
     * Définit la valeur de la propriété commentaireParamCE.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCommentaireParamCE(JAXBElement<String> value) {
        this.commentaireParamCE = value;
    }

    /**
     * Obtient la valeur de la propriété codEtpPorteuse.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodEtpPorteuse() {
        return codEtpPorteuse;
    }

    /**
     * Définit la valeur de la propriété codEtpPorteuse.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodEtpPorteuse(JAXBElement<String> value) {
        this.codEtpPorteuse = value;
    }

    /**
     * Obtient la valeur de la propriété codVrsVetPorteuse.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodVrsVetPorteuse() {
        return codVrsVetPorteuse;
    }

    /**
     * Définit la valeur de la propriété codVrsVetPorteuse.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodVrsVetPorteuse(JAXBElement<String> value) {
        this.codVrsVetPorteuse = value;
    }

    /**
     * Obtient la valeur de la propriété listElpPorte.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link TableauElpPorteDTO2 }{@code >}
     *     
     */
    public JAXBElement<TableauElpPorteDTO2> getListElpPorte() {
        return listElpPorte;
    }

    /**
     * Définit la valeur de la propriété listElpPorte.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link TableauElpPorteDTO2 }{@code >}
     *     
     */
    public void setListElpPorte(JAXBElement<TableauElpPorteDTO2> value) {
        this.listElpPorte = value;
    }

    /**
     * Obtient la valeur de la propriété listTypHeur.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link TableauTypeHeureDTO2 }{@code >}
     *     
     */
    public JAXBElement<TableauTypeHeureDTO2> getListTypHeur() {
        return listTypHeur;
    }

    /**
     * Définit la valeur de la propriété listTypHeur.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link TableauTypeHeureDTO2 }{@code >}
     *     
     */
    public void setListTypHeur(JAXBElement<TableauTypeHeureDTO2> value) {
        this.listTypHeur = value;
    }

}

==> apo-ws-client-6.00.51.2-sources.jar: fr/univlorraine/apowsclient/creationSE/ParametrageAnnuelCeDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ParametrageAnnuelCeDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ParametrageAnnuelCeDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codAnneeUni" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codSectionCnu" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codSectionCnuSec" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codRegroupementSectionCnu" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="temCalculCharge" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="temNormeContrainte" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="temElpPorteur" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="commentaireParamCE" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codEtpPorteuse" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codVrsVetPorteuse" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="listElpPorte" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauElpPorteDTO"/&gt;
 *         &lt;element name="listTypHeur" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauTypeHeureDTO"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ParametrageAnnuelCeDTO", namespace = "ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codAnneeUni",
    "codSectionCnu",
    "codSectionCnuSec",
    "codRegroupementSectionCnu",
    "temCalculCharge",
    "temNormeContrainte",
    "temElpPorteur",
    "commentaireParamCE",
    "codEtpPorteuse",
    "codVrsVetPorteuse",
    "listElpPorte",
    "listTypHeur"
})
public class ParametrageAnnuelCeDTO {

    @XmlElement(required = true)
    protected String codAnneeUni;
    @XmlElement(required = true)
    protected String codSectionCnu;
    @XmlElement(required = true)
    protected String codSectionCnuSec;
    @XmlElement(required = true, nillable = true)
    protected String codRegroupementSectionCnu;
    @XmlElement(required = true, nillable = true)
    protected String temCalculCharge;
    @XmlElement(required = true, nillable = true)
    protected String temNormeContrainte;
    @XmlElement(required = true, nillable = true)
    protected String temElpPorteur;
    @XmlElement(required = true, nillable = true)
    protected String commentaireParamCE;
    @XmlElement(required = true, nillable = true)
    protected String codEtpPorteuse;
    @XmlElement(required = true, nillable = true)
    protected String codVrsVetPorteuse;
    @XmlElement(required = true, nillable = true)
    protected TableauElpPorteDTO2 listElpPorte;
    @XmlElement(required = true, nillable = true)
    protected TableauTypeHeureDTO2 listTypHeur;

    /**
     * Obtient la valeur de la propriété codAnneeUni.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodAnneeUni() {
        return codAnneeUni;
    }

    /**
     * Définit la valeur de la propriété codAnneeUni.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodAnneeUni(String value) {
        this.codAnneeUni = value;
    }

    /**
     * Obtient la valeur de la propriété codSectionCnu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodSectionCnu() {
        return codSectionCnu;
    }

    /**
     * Définit la valeur de la propriété codSectionCnu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodSectionCnu(String value) {
        this.codSectionCnu = value;
    }

    /**
     * Obtient la valeur de la propriété codSectionCnuSec.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodSectionCnuSec() {
        return codSectionCnuSec;
    }

    /**
     * Définit la valeur de la propriété codSectionCnuSec.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodSectionCnuSec(String value) {
        this.codSectionCnuSec = value;
    }

    /**
     * Obtient la valeur de la propriété codRegroupementSectionCnu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodRegroupementSectionCnu() {
        return codRegroupementSectionCnu;
    }

    /**
     * Définit la valeur de la propriété codRegroupementSectionCnu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodRegroupementSectionCnu(String value) {
        this.codRegroupementSectionCnu = value;
    }

    /**
     * Obtient la valeur de la propriété temCalculCharge.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemCalculCharge() {
        return temCalculCharge;
    }

    /**
     * Définit la valeur de la propriété temCalculCharge.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemCalculCharge(String value) {
        this.temCalculCharge = value;
    }

    /**
     * Obtient la valeur de la propriété temNormeContrainte.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemNormeContrainte() {
        return temNormeContrainte;
    }

    /**
     * Définit la valeur de la propriété temNormeContrainte.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemNormeContrainte(String value) {
        this.temNormeContrainte = value;
    }

    /**
     * Obtient la valeur de la propriété temElpPorteur.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemElpPorteur() {
        return temElpPorteur;
    }

    /**
     * Définit la valeur de la propriété temElpPorteur.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemElpPorteur(String value) {
        this.temElpPorteur = value;
    }

    /**
     * Obtient la valeur de la propriété commentaireParamCE.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCommentaireParamCE() {
        return commentaireParamCE;
    }

    /**
     * Définit la valeur de la propriété commentaireParamCE.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCommentaireParamCE(String value) {
        this.commentaireParamCE = value;
    }

    /**
     * Obtient la valeur de la propriété codEtpPorteuse.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtpPorteuse() {
        return codEtpPorteuse;
    }

    /**
     * Définit la valeur de la propriété codEtpPorteuse.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtpPorteuse(String value) {
        this.codEtpPorteuse = value;
    }

    /**
     * Obtient la valeur de la propriété codVrsVetPorteuse.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVrsVetPorteuse() {
        return codVrsVetPorteuse;
    }

    /**
     * Définit la valeur de la propriété codVrsVetPorteuse.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVrsVetPorteuse(String value) {
        this.codVrsVetPorteuse = value;
    }

    /**
     * Obtient la valeur de la propriété listElpPorte.
     * 
     * @return
     *     possible object is
     *     {@link TableauElpPorteDTO2 }
     *     
     */
    public TableauElpPorteDTO2 getListElpPorte() {
        return listElpPorte;
    }

    /**
     * Définit la valeur de la propriété listElpPorte.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauElpPorteDTO2 }
     *     
     */
    public void setListElpPorte(TableauElpPorteDTO2 value) {
        this.listElpPorte = value;
    }

    /**
     * Obtient la valeur de la propriété listTypHeur.
     * 
     * @return
     *     possible object is
     *     {@link TableauTypeHeureDTO2 }
     *     
     */
    public TableauTypeHeureDTO2 getListTypHeur() {
        return listTypHeur;
    }

    /**
     * Définit la valeur de la propriété listTypHeur.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauTypeHeureDTO2 }
     *     
     */
    public void setListTypHeur(TableauTypeHeureDTO2 value) {
        this.listTypHeur = value;
    }

}
